# USER SETTINGS SCRIPT FOR SENDING PUSHOVER NOTIFICATIONS WITH A GIF FILE ATTACHMENT
#
# KEY POINTS: 
#   1. This script is intended to be used by companion script 'pushover_resize.ps1'
#   2. This script must be located in the same folder as script 'pushover_resize.ps1'
#   3. This script is suitable for 'BI_gif_tool.ps1' versions V1+
#
# Created by jaydeel at ipcamtalk.com

# ================================================
# USER SETTINGS...

# REQUIRED SETTINGS

	# [REQUIRED] ENTER THIS APP'S FOLDER LOCATION
	# ... [string] like, "D:\BI_gif_tool"
	# ... This will be the root folder for app-created CSV, GIF, JPG, archived DAT files
	$app_path = "YOUR_APP_FOLDER_PATH"

	# [REQUIRED] ENTER LOCATION OF BLUE IRIS 'DAT' FILES (YOUR BLUE 'ALERTS' FOLDER)
	# ... [string] 
	# ... Default is "D:\BlueIris\Alerts"
	$bi_alert_folder_path = "YOUR_BLUE_IRIS_ALERTS_FOLDER_PATH"

	# [REQUIRED] ENTER LOCATION OF BLUE IRIS 'BVR' FILES (YOUR BLUE 'NEW' FOLDER)
	# ... [string] 
	# ... Default is "D:\BlueIris\New"
	$bi_new_folder_path = "YOUR_BLUE_IRIS_NEW_FOLDER_PATH"

	# [REQUIRED] ENTER BLUE WEBSERVER ADDRESS & PORT
	# ... [string] like, "192.168.1.3:81"
	# ... to use credentials, be sure to uncheck 'Use secure session keys and login page' 
	#     in Blue Iris settings: click Settings > Web server > Advanced
	$bi_webserver = "YOUR_BI_SERVER_ADDRESS:PORT"

	# [REQUIRED] ENTER BLUE IRIS WEBSERVER USERNAME & PASSWORD 
	# ... [string] 
	# ... NOTE: ACCOUNT MUST BE ADMIN TO POST TO CUSTOM MESSAGES TO THE BLUE IRIS LOGFILE
	$bi_user_name = "YOUR_BI_USER_NAME"
	$bi_user_pw = "YOUR_BI_USER_PASSORD"

	# ENTER PUSHOVER API APPLICATION TOKEN
	# ... TIP: consider adding a 'PowerShell' application to your https://pushover.net/ account
	$po_app_token = "YOUR_API_APPLICATION_TOKEN"

	# ENTER PUSHOVER API USER KEY
	# ... https://pushover.net/
	$po_user_token = "YOUR_API_USER_KEY"

# OPTIONAL SETTINGS

# ... SCRIPT OPTIONS

	# OPT IN/OUT OF BACKGROUND MESSAGING
	# ... [boolean]
	# ... Default is $true
	# ... Key Points: 
	#     1. Background messages are enabled only if script is running in the background
	#     2. This global setting may be overridden by argument '-Quiet Y'
	$bg_msgs_on = $false
	#$bg_msgs_on = $true

# ... GIF FILE GLOBAL OPTIONS

	# ENTER GIF'S HEIGHT DIMENSION
	# ... [integer] units are pix
	# ... Default is 320
	# ... The aspect ratio is unchanged by resizing
	# ... Note: if 0 with $img_quality < 100, the target width = the source image width
	# ...       if 0 with $img_quality = 100, the image is used as-is
	$gif_height = 320

	# ENTER GIF FRAMES PER SECOND
	# ... [integer] 
	# ... Default is 2
	# ... Use a higher value to make the GIF run faster
	$gif_fps = 2

	# ENTER MAX LIFETIME FOR ARCHIVED GIF FILES
	# ... All GIF files created by this script are automatically archived to folder '$app_path\_gif_archive'
	# ... To prevent this folder from growing excessively large, this setting deletes GIF files after a given age
	# ... TIP: Use 0 to disable monitoring of the this archive folder
	# ... Default is 720 hours (30 days)
	$gif_archive_lifetime_hours = 720

# ... SOURCING GIF FILES FROM BLUE IRIS VIDEO CLIPS

	# ENTER COUNT OF JPGS TO USE IN THE GIF ANIMATION
	# ... [integer] 
	# ... Default is 10
	$gif_images_cnt = 10

	# ENTER PERCENTAGE OF ALERT CLIP TO TRIM FOR GIF ANIMATION
	# ... Use to eliminate portion of full alert clip
	# ... Separate settings for left-side (beg) and right-right (end)
	# ... [integer] 0 to 99
	# ... Default is 0
	$gif_trim_beg = 0
	$gif_trim_end = 40

	# ENTER PERCENTAGE OF ALERT CLIP TO TRIM FROM RIGHT SIDE FOR GIF ANIMATION
	# ... One setting each for left-side (beg) and right-right (end)
	# ... [object] like, @{ 'ai_label_1' = pct ; 'ai_label_1' = pct ; ... } 
	# ... Use positive values for fast-moving objects (to use less of the clip)
	# ... Use negative values for slow/random-moving objects (to use more of the clip)
	# ... NOTE: The sum of $gif_trim_beg, $gif_trim_end and EACH OF THESE VALUES must be between 0 and 100
	# ... Default is @{}
	<# $gif_trim_end_custom = @{
		'vehicle' = 20  # Use less of the clip for fast moving objects
		'car' = 10
		'truck' = 30
		#'person' = 5
		#'dog' = -40  # Use the whole clip for slow/random moving objects
		#'cat' = -40 
	} #>
	$gif_trim_end_custom = @{}

# ... SOURCING GIF FILES FROM BLUE IRIS 'DAT' FILES

	# ENTER REQUIRED NUMBER OF JPGs IN 'DAT' FILE
	# ... [integer] 
	# ... Default is 4
	# ... Otherwise, the GIF will be made from the BLUE IRIS VIDEO CLIP 
	$gif_DAT_reqd_images = 6

	# OPT IN TO 'DAT' TAGS TO PUSHOVER MESSAGES
	# ... The tags is like ' (DAT9)' where 9 is the number of JPGs extracted from the DAT file
	# ... [boolean] 
	# ... Default is $true
	$append_DAT_tag_flg = $true
	#$append_DAT_tag_flg = $false

	# ENTER MAX LIFETIME FOR ARCHIVED 'DAT' FILES
	# ... DAT files archived by this script are saved to folder '$app_path\_dat_archive'
	# ... To prevent this folder from growing excessively large, this setting deletes DAT files after a given age
	# ... TIP: Use 0 to disable monitoring of the this archive folder
	# ... Default is 720 hours (30 days)
	$dat_archive_lifetime_hours = 720

# ... PUSHOVER NOTIFICATION DEFAULTS

	# ENTER PUSHOVER MESSAGE PRIORITY
	# ... (integer) -2|-1|0|1|2; -2=lowest, -1=low(silent), 0=normal, 1=high-priority, 2=emergency
	# ... see https://pushover.net/api#priority
	$po_priority = 2

	# ENTER PUSHOVER SOUND
	# ... blank ("") is default sound
	# ... see https://pushover.net/api#sounds
	$po_sound = ""  # default sound
	#$po_sound = "siren"  # built-in sound
	#$po_sound = "not-kiddin"  # custom sound

	# ENTER PUSHOVER DEVICE(S)
	# ... blank ("") sends to all devices
	# ... may be comma-delimited list.
	# ... see https://pushover.net/api
	$po_device = ""  # all devices
	#$po_device = "galaxy-s21"  # single device
	#$po_device = "galaxy-s21,iPhoneXS"  # multiple devices

	# ENTER PUSHOVER RETRY PARAMETER (SECONDS)
	# ... Required for priority=2 messages (emergency)
	# ... see https://pushover.net/api#priority
	$po_retry = 30

	# ENTER PUSHOVER EXPIRE PARAMETER (SECONDS)
	# ... Required for priority=2 messages (emergency)
	# ... see https://pushover.net/api#priority
	$po_expire = 300

	# ENTER PUSHOVER EMERGENCE PRIORITY TAGS
	# ... blank ("") is default tag
	# ... see https://pushover.net/api#priority
	$po_tags = ""
	#$po_tags = "a=BI,c=&CAM,g=Front"  # custom tags

# ... LOGGING TO THE BLUE IRIS LOGFILE

	# OPT-IN TO POSTING CUSTOM MESSAGES TO THE BLUE IRIS LOG
	# ... expecting $false or $true (default = $false)
	#$post_to_BI_logfile_flg = $false
	$post_to_BI_logfile_flg = $true

	# OPT-IN TO USE CREDENTIALS FOR POSTING TO THE BLUE IRIS LOGFILE
	# ... expecting $false or $true (default = $false)
	$post_w_creds_flg = $false
	#$post_w_creds_flg = $true

	# OPT IN TO LOGGING ALL EVENTS (NOT JUST ERRORS)
	# ... [boolean]
	# ... expecting $false or $true (default = $false)
	$post_all_events = $false
	#$post_all_events = $true

# END USER SETTINGS
# ===============================================
